pub struct AstGraphHash {
pub bytes: [u8; 32],
}Expand description
32-byte BLAKE3 content hash; same shape as
lockfile_graph::CanonicalGraphHash. Kept duplicated rather than
pulled in to keep the module’s dependency surface tight.
Fields
bytes: [u8; 32]Trait Implementations
Sourceimpl Archive for AstGraphHash
impl Archive for AstGraphHash
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedAstGraphHash
type Archived = ArchivedAstGraphHash
The archived representation of this type. Read more
Sourcetype Resolver = AstGraphHashResolver
type Resolver = AstGraphHashResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for AstGraphHash
impl Clone for AstGraphHash
Sourcefn clone(&self) -> AstGraphHash
fn clone(&self) -> AstGraphHash
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for AstGraphHash
Sourceimpl Debug for AstGraphHash
impl Debug for AstGraphHash
Sourceimpl<'de> Deserialize<'de> for AstGraphHash
impl<'de> Deserialize<'de> for AstGraphHash
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<__D: Fallible + ?Sized> Deserialize<AstGraphHash, __D> for Archived<AstGraphHash>
impl<__D: Fallible + ?Sized> Deserialize<AstGraphHash, __D> for Archived<AstGraphHash>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<AstGraphHash, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<AstGraphHash, <__D as Fallible>::Error>
Deserializes using the given deserializer
impl Eq for AstGraphHash
Sourceimpl Hash for AstGraphHash
impl Hash for AstGraphHash
Sourceimpl PartialEq for AstGraphHash
impl PartialEq for AstGraphHash
Sourcefn eq(&self, other: &AstGraphHash) -> bool
fn eq(&self, other: &AstGraphHash) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for AstGraphHash
impl Serialize for AstGraphHash
impl StructuralPartialEq for AstGraphHash
Sourceimpl TataraDomain for AstGraphHash
impl TataraDomain for AstGraphHash
Sourcefn compile_from_args(args: &[Sexp]) -> Result<Self>
fn compile_from_args(args: &[Sexp]) -> Result<Self>
Parse the argument list (everything after the keyword) into Self.