pub struct AstNodeForm {
pub id: NodeId,
pub kind: AstNodeKind,
}Expand description
One AST node in the graph.
Fields
id: NodeIdkind: AstNodeKindTrait Implementations
Sourceimpl Archive for AstNodeForm
impl Archive for AstNodeForm
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedAstNodeForm
type Archived = ArchivedAstNodeForm
The archived representation of this type. Read more
Sourcetype Resolver = AstNodeFormResolver
type Resolver = AstNodeFormResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for AstNodeForm
impl Clone for AstNodeForm
Sourcefn clone(&self) -> AstNodeForm
fn clone(&self) -> AstNodeForm
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AstNodeForm
impl Debug for AstNodeForm
Sourceimpl<'de> Deserialize<'de> for AstNodeForm
impl<'de> Deserialize<'de> for AstNodeForm
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<__D: Fallible + ?Sized> Deserialize<AstNodeForm, __D> for Archived<AstNodeForm>where
NodeId: Archive,
<NodeId as Archive>::Archived: Deserialize<NodeId, __D>,
AstNodeKind: Archive,
<AstNodeKind as Archive>::Archived: Deserialize<AstNodeKind, __D>,
impl<__D: Fallible + ?Sized> Deserialize<AstNodeForm, __D> for Archived<AstNodeForm>where
NodeId: Archive,
<NodeId as Archive>::Archived: Deserialize<NodeId, __D>,
AstNodeKind: Archive,
<AstNodeKind as Archive>::Archived: Deserialize<AstNodeKind, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<AstNodeForm, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<AstNodeForm, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl PartialEq for AstNodeForm
impl PartialEq for AstNodeForm
Sourcefn eq(&self, other: &AstNodeForm) -> bool
fn eq(&self, other: &AstNodeForm) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for AstNodeForm
impl Serialize for AstNodeForm
impl StructuralPartialEq for AstNodeForm
Sourceimpl TataraDomain for AstNodeForm
impl TataraDomain for AstNodeForm
Sourcefn compile_from_args(args: &[Sexp]) -> Result<Self>
fn compile_from_args(args: &[Sexp]) -> Result<Self>
Parse the argument list (everything after the keyword) into Self.