Canonical sui CLI invocations — symmetric with nix_cli.
Functions
- build_
dry_ run sui build --dry-run --print-out-paths --no-link <installable>.- eval_
expr sui eval --json <expr>— evaluate a literal expression as positional installable (sui treats expressions and installables uniformly through this path).- eval_
expr_ explicit sui eval --impure --json --expr <expr>— explicit--exprfor cases where the input might otherwise be parsed as a path-style installable.- eval_
installable sui eval --json <installable>— evaluate a flake-attribute installable.- flake_
check sui flake check <flake-ref>.- flake_
show sui flake show --json <flake-ref>.