pub struct FetchOutcome {
pub store_path: String,
pub nar_hash: String,
}Expand description
Result of a fetcher run — the store path the fetched content landed at, plus its content hash.
Fields
store_path: Stringnar_hash: StringTrait Implementations
Sourceimpl Clone for FetchOutcome
impl Clone for FetchOutcome
Sourcefn clone(&self) -> FetchOutcome
fn clone(&self) -> FetchOutcome
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FetchOutcome
impl Debug for FetchOutcome
impl Eq for FetchOutcome
Sourceimpl PartialEq for FetchOutcome
impl PartialEq for FetchOutcome
Sourcefn eq(&self, other: &FetchOutcome) -> bool
fn eq(&self, other: &FetchOutcome) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for FetchOutcome