pub struct NamedEdge {
pub name: String,
pub target: NodeId,
}Expand description
(name, target) edge in the resolved input graph.
Fields
name: Stringtarget: NodeIdTrait Implementations
Sourceimpl Archive for NamedEdge
impl Archive for NamedEdge
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedNamedEdge
type Archived = ArchivedNamedEdge
The archived representation of this type. Read more
Sourcetype Resolver = NamedEdgeResolver
type Resolver = NamedEdgeResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl<'de> Deserialize<'de> for NamedEdge
impl<'de> Deserialize<'de> for NamedEdge
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for NamedEdge
impl StructuralPartialEq for NamedEdge
Sourceimpl TataraDomain for NamedEdge
impl TataraDomain for NamedEdge
Sourcefn compile_from_args(args: &[Sexp]) -> Result<Self>
fn compile_from_args(args: &[Sexp]) -> Result<Self>
Parse the argument list (everything after the keyword) into Self.