pub struct ModuleGraphHash {
pub bytes: [u8; 32],
}Expand description
32-byte BLAKE3 hash. Same shape as the lockfile / AST graph hashes; kept separate so the type system distinguishes which graph kind a hash refers to.
Fields
bytes: [u8; 32]Trait Implementations
Sourceimpl Archive for ModuleGraphHash
impl Archive for ModuleGraphHash
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedModuleGraphHash
type Archived = ArchivedModuleGraphHash
The archived representation of this type. Read more
Sourcetype Resolver = ModuleGraphHashResolver
type Resolver = ModuleGraphHashResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for ModuleGraphHash
impl Clone for ModuleGraphHash
Sourcefn clone(&self) -> ModuleGraphHash
fn clone(&self) -> ModuleGraphHash
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ModuleGraphHash
Sourceimpl Debug for ModuleGraphHash
impl Debug for ModuleGraphHash
Sourceimpl<'de> Deserialize<'de> for ModuleGraphHash
impl<'de> Deserialize<'de> for ModuleGraphHash
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<__D: Fallible + ?Sized> Deserialize<ModuleGraphHash, __D> for Archived<ModuleGraphHash>
impl<__D: Fallible + ?Sized> Deserialize<ModuleGraphHash, __D> for Archived<ModuleGraphHash>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<ModuleGraphHash, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<ModuleGraphHash, <__D as Fallible>::Error>
Deserializes using the given deserializer
impl Eq for ModuleGraphHash
Sourceimpl Hash for ModuleGraphHash
impl Hash for ModuleGraphHash
Sourceimpl PartialEq for ModuleGraphHash
impl PartialEq for ModuleGraphHash
Sourceimpl Serialize for ModuleGraphHash
impl Serialize for ModuleGraphHash
impl StructuralPartialEq for ModuleGraphHash
Sourceimpl TataraDomain for ModuleGraphHash
impl TataraDomain for ModuleGraphHash
Sourcefn compile_from_args(args: &[Sexp]) -> Result<Self>
fn compile_from_args(args: &[Sexp]) -> Result<Self>
Parse the argument list (everything after the keyword) into Self.